PALM-meteo: palmmeteo_stdplugins.meteo Namespace Reference

PALM-meteo

Loading...
Searching...
No Matches
Classes | Variables
palmmeteo_stdplugins.meteo Namespace Reference

## Classes
class | EmisPlugin
class | RequiresMeteoPluginMixin
class | SomeMeteoPlugin

## Variables
dict | available_meteo_vars
| required_variables = set()

## Variable Documentation

## ◆ available_meteo_vars

dict palmmeteo_stdplugins.meteo.available_meteo_vars

Initial value:
1= {
2 'tas': {'desc': 'temperature at surface', 'units': 'K'},
3 'ta': {'desc': '3D temperature', 'units': 'K'},
4 'qas': {'desc': 'specific humidity at the surface', 'units': 'kg/kg'},
5 'qa': {'desc': '3D specific humidity', 'units': '1'},
6 'rsds': {'desc': 'surface incident SW radiation for BVOC', 'units': 'W/m2'},
7 'pa': {'desc': '3D pressure', 'units': 'Pa'},
8 'zf': {'desc': 'layer interface heights', 'units': 'm'},
9 'ua': {'desc': 'U-wind', 'units': 'm/s'},
10 'va': {'desc': 'V-wind', 'units': 'm/s'}
11}

## ◆ required_variables

palmmeteo_stdplugins.meteo.required_variables = set()